summaryrefslogtreecommitdiff
path: root/src/mongo/db/clientcursor.h
diff options
context:
space:
mode:
authorDavid Storch <david.storch@10gen.com>2014-07-15 17:30:02 -0400
committerDavid Storch <david.storch@10gen.com>2014-07-22 09:24:11 -0400
commit7ffac7f351b80f84589349e44693a94d5cc5e14c (patch)
tree3707298920eabe877af03963f3f61f74c5a61fc5 /src/mongo/db/clientcursor.h
parentfb270d89cbcfdb98c3cee3e631c76ca035c7b4f0 (diff)
downloadmongo-7ffac7f351b80f84589349e44693a94d5cc5e14c.tar.gz
SERVER-14407 replace Runner with PlanExecutor
Diffstat (limited to 'src/mongo/db/clientcursor.h')
-rw-r--r--src/mongo/db/clientcursor.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/clientcursor.h b/src/mongo/db/clientcursor.h
index 252212a712a..1b0f323c49d 100644
--- a/src/mongo/db/clientcursor.h
+++ b/src/mongo/db/clientcursor.h
@@ -33,7 +33,7 @@
#include "mongo/db/diskloc.h"
#include "mongo/db/jsobj.h"
#include "mongo/db/keypattern.h"
-#include "mongo/db/query/runner.h"
+#include "mongo/db/query/plan_executor.h"
#include "mongo/s/collection_metadata.h"
#include "mongo/util/background.h"
#include "mongo/util/net/message.h"
@@ -57,7 +57,7 @@ namespace mongo {
*/
class ClientCursor : private boost::noncopyable {
public:
- ClientCursor(const Collection* collection, Runner* runner,
+ ClientCursor(const Collection* collection, PlanExecutor* exec,
int qopts = 0, const BSONObj query = BSONObj());
ClientCursor(const Collection* collection);
@@ -77,7 +77,7 @@ namespace mongo {
* goes through killing cursors.
* It removes the responsiilibty of de-registering from ClientCursor.
* Responsibility for deleting the ClientCursor doesn't change from this call
- * see Runner::kill.
+ * see PlanExecutor::kill.
*/
void kill();
@@ -115,10 +115,10 @@ namespace mongo {
OpTime getSlaveReadTill() const { return _slaveReadTill; }
//
// Query-specific functionality that may be adapted for the Runner.
//
- Runner* getRunner() const { return _runner.get(); }
+ PlanExecutor* getExecutor() const { return _exec.get(); }
int queryOptions() const { return _queryOptions; }
// Used by ops/query.cpp to stash how many results have been returned by a query.
@@ -129,7 +129,7 @@ namespace mongo {
/**
* Is this ClientCursor backed by an aggregation pipeline. Defaults to false.
*
- * Agg Runners differ from others in that they manage their own locking internally and
+ * Agg executors differ from others in that they manage their own locking internally and
* should not be killed or destroyed when the underlying collection is deleted.
*
* Note: This should *not* be set for the internal cursor used as input to an aggregation.
@@ -200,7 +200,7 @@ namespace mongo {
//
// The underlying execution machinery.
//
- scoped_ptr<Runner> _runner;
+ scoped_ptr<PlanExecutor> _exec;
};
/**
@@ -115,10 +115,10 @@ namespace mongo {
OpTime getSlaveReadTill() const { return _slaveReadTill; }
//
- // Query-specific functionality that may be adapted for the Runner.
+ // Query-specific functionality that may be adapted for the PlanExecutor.
//